@@ -26,18 +26,18 @@
 #' Use \code{dictionaries()} or \code{find.dictionaries()} for more options
 #' (See \code{\link{SemNetDictionaries}} for more details)
 #' 
+#' @param add.path Character.
+#' Path to additional dictionaries to be found.
+#' DOES NOT search recursively (through all folders in path)
+#' to avoid time intensive search.
+#' Set to \code{"choose"} to open an interactive directory explorer
+#' 
 #' @param continue List.
 #' A result previously unfinished that still needs to be completed.
 #' Allows you to continue to manually spell-check their data
 #' after you've closed or errored out.
 #' Defaults to \code{NULL}
 #' 
-#' @param walkthrough Boolean.
-#' Whether a walkthrough should be provided (recommended for first time users).
-#' Defaults to \code{NULL}, which will ask whether you would like a walkthrough.
-#' Set to \code{TRUE} to do the walkthrough.
-#' Set to \code{FALSE} to skip the walkthrough
-#' 
 #' @return This function returns a list containing the following objects:
 #' 
 #' \item{binary}{A matrix of responses where each row represents a participant
@@ -48,11 +48,11 @@
 #' 
 #' \itemize{
 #' 
-#' \item{clean}
+#' \item{\code{clean}}
 #' {A response matrix that has been spell-checked and de-pluralized with duplicates removed.
 #' This can be used as a final dataset for analyses (e.g., fluency of responses)}
 #' 
-#' \item{original}
+#' \item{\code{original}}
 #' {The original response matrix that has had white spaces before and
 #' after words response. Also converts all upper-case letters to lower case}
 #' 
@@ -116,13 +116,13 @@
 #' 
 #' @export
 # Text Cleaner----
-# Updated 19.04.2020
+# Updated 08.09.2020
 # Major update: 19.04.2020
 textcleaner <- function(data = NULL, miss = 99,
                         partBY = c("row","col"),
-                        dictionary = NULL,
-                        continue = NULL,
-                        walkthrough = NULL)
+                        dictionary = NULL, add.path = NULL,
+                        continue = NULL#, walkthrough = NULL
+                        )
 {
   # Check if user is continuing from a previous point
   if(is.null(continue))
@@ -174,15 +174,21 @@ textcleaner <- function(data = NULL, miss = 99,
     ## Obtain unique responses for efficient spell-checking
     uniq.resp <- na.omit(unique(unlist(data)))
     
+    # Sort out dictionaries
+    if(is.null(dictionary))
+    {dictionary <- "general"}
+    
     # Perform spell-check
     spell.check <- try(
       spellcheck.dictionary(uniq.resp = uniq.resp,
-                            dictionary = ifelse(is.null(dictionary), "general", dictionary),
-                            data = data, walkthrough = walkthrough),
+                            dictionary = dictionary,
+                            add.path = add.path,
+                            data = data#, walkthrough = walkthrough
+                            ),
       silent <- TRUE
     )
     
-  }else if(length(continue) == 14) # Continue spell-check
+  }else if(length(continue) != 3) # Continue spell-check
   {spell.check <- spellcheck.dictionary(continue = continue)
   }else{spell.check <- continue}
   
@@ -247,7 +253,6 @@ textcleaner <- function(data = NULL, miss = 99,
   
   ## Make sure to replace faux "NA" with real NA
   corrected$corrected[which(corrected$corrected == "NA")] <- NA
-  res$responses$checked <- as.data.frame(corrected$corrected, stringsAsFactors = FALSE)
   
   ## Cleaned responses (no instrusions or perseverations)
   cleaned.list <- apply(corrected$corrected, 1, function(x){unique(na.omit(x))})
@@ -266,7 +271,6 @@ textcleaner <- function(data = NULL, miss = 99,
   
   res$responses$clean <- cleaned.matrix
   
-  
   # Convert to binary response matrix (error catch)
   res$responses$binary <- try(
     resp2bin(corrected$corrected),
@@ -284,8 +288,56 @@ textcleaner <- function(data = NULL, miss = 99,
   colnames(behavioral)[3] <- "Appropriate"
   res$behavioral <- as.data.frame(behavioral)
 
-  #make 'textcleaner' class
+  # Make 'textcleaner' class
   class(res) <- "textcleaner"
+  
+  # Correct auto-corrections
+  res <- try(correct.changes(res), silent = TRUE)
+  
+  if(any(class(res) == "try-error"))
+  {
+    error.fun(res, "correct.changes", "textcleaner")
+    
+    return(res)
+  }
+  
+  # Let user know spell-check is complete
+  Sys.sleep(1)
+  message("\nPreprocessing complete.\n")
+  Sys.sleep(2)
+  
+  # Let user know where to send their dictionaries and monikers
+  dictionary.output <- paste(
+    textsymbol("bullet"),
+    "Dictionary output: `OBJECT_NAME$dictionary`",
+    sep = " "
+  )
+  
+  moniker.output <- paste(
+    textsymbol("bullet"),
+    "Moniker output: `OBJECT_NAME$spellcheck$manual`",
+    sep = " "
+  )
+  
+  cat(
+    
+    colortext(
+      
+      paste(
+        "Consider submitting your dictionary and spelling corrections (i.e., monikers) to:\n\n",
+        "https://github.com/AlexChristensen/SemNetDictionaries/issues/new/choose\n\n",
+        dictionary.output, "\n\n",
+        moniker.output, "\n\n"
+      ),
+      
+      defaults = "message"
+      
+    )
+  
+  )
+  
+  Sys.sleep(2)
+  
 
   return(res)
 }
